/*
 * hs300x.c
 *
 *  Created on: 2023年2月14日
 *      Author: Administrator
 */
#include "hs300x.h"
#include "stdio.h"
#include "user_uart.h"



/* Sequence */
typedef enum e_demo_sequence
{
    DEMO_SEQUENCE_1 = (1),
    DEMO_SEQUENCE_2,
    DEMO_SEQUENCE_3,
    DEMO_SEQUENCE_4,
    DEMO_SEQUENCE_5,
    DEMO_SEQUENCE_6,
} demo_sequence_t;

/* Callback status */
typedef enum e_hs3003_callback_status
{
    HS3003_CALLBACK_STATUS_WAIT = (0),
    HS3003_CALLBACK_STATUS_SUCCESS,
    HS3003_CALLBACK_STATUS_REPEAT,
} hs3003_callback_status_t;

#define tx_buf_len       8

#define SENSOR_TEMP_RANGE_MAX (80)
#define SENSOR_TEMP_RANGE_MIN (-10)
#define SENSOR_HUMI_RANGE_MAX (100)
#define SENSOR_HUMI_RANGE_MIN (0)

/* Definitions of Mask Data for A/D data */
#define RM_HS300X_MASK_HUMIDITY_UPPER_0X3F       (0x3F)
#define RM_HS300X_MASK_TEMPERATURE_LOWER_0XFC    (0xFC)
#define RM_HS300X_MASK_STATUS_0XC0               (0xC0)

/* Definitions for Status Bits of A/D Data */
#define RM_HS300X_DATA_STATUS_VALID              (0x00) // Status-bit: Valid data

/* Definitions for Calculation */
#define RM_HS300X_CALC_STATIC_VALUE              (16383.0F)
#define RM_HS300X_CALC_HUMD_VALUE_100            (100.0F)
#define RM_HS300X_CALC_TEMP_C_VALUE_165          (165.0F)
#define RM_HS300X_CALC_TEMP_C_VALUE_40           (40.0F)
#define RM_HS300X_CALC_DECIMAL_VALUE_100         (100.0F)


/* See Developer Assistance in the project */
void g_comms_i2c_bus0_quick_setup(void);
void g_hs300x_sensor0_quick_setup(void);


static volatile hs3003_callback_status_t  hs3003_callback_status;

void g_comms_i2c_bus0_quick_setup(void)
{
    fsp_err_t err;
    err = R_IIC_MASTER_Open(&g_i2c_master0_ctrl, &g_i2c_master0_cfg);
    assert(FSP_SUCCESS == err);
}


void IIC_master_callback(i2c_master_callback_args_t * p_args)
{
    if (HS3003_CALLBACK_STATUS_SUCCESS == p_args->event)
    {
        hs3003_callback_status = HS3003_CALLBACK_STATUS_SUCCESS;
    }
    else
    {
        hs3003_callback_status = HS3003_CALLBACK_STATUS_REPEAT;
    }
}

void hs300x_data_entry(void)
{
    fsp_err_t err;
    uint8_t r_buf[4] = {0};
    int i;
    uint8_t tx_buf[tx_buf_len] = {0x5A,0xA5,0x00,0x00,0x00,0x00,0xAA,0x0A};
    uint8_t data[2] = {0x00,0x00};

    g_comms_i2c_bus0_quick_setup();


    err = R_IIC_MASTER_Write(&g_i2c_master0_ctrl,data,1,0);
    R_BSP_SoftwareDelay(30000,BSP_DELAY_UNITS_MICROSECONDS);
    err = R_IIC_MASTER_Read(&g_i2c_master0_ctrl,&r_buf,4,1);
    if(err == FSP_SUCCESS)
    {
        if ((r_buf[0] & RM_HS300X_MASK_STATUS_0XC0) != RM_HS300X_DATA_STATUS_VALID)
        {
            printf("turn time out");
        }
        printf("\n");
        tx_buf[2] = r_buf[0];
        tx_buf[3] = r_buf[1];
        tx_buf[4] = r_buf[2];
        tx_buf[5] = r_buf[3];
        for(i=0; i<8; i++)
            printf("%c",tx_buf[i]);

    }
    else {
        printf("read hs3003 erro!\n");
    }


}

